/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Elimina"

, "Reply"
: "Respon"

, "Reply To All"
: "Respon a tots"

, "Forward"
: "Reenvia"

, "Print Message"
: "Imprimeix el missatge"

, "Print Preview"
: "Previsualitza la impressió"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  ""
 ,""

]
, "Account, Accounts"
: [
  "Compte"
 ,"Comptes"

]
, "Account Name"
: "Nom de compte"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Correu electrònic de l'usuari"

, "User Name (From)"
: "Nom de l'usuari (des de)"

, "Organization"
: "Organització"

, "Signature position"
: ""

, "Above the quote"
: ""

, "Below the quote"
: ""

, "IMAP"
: "IMAP"

, "Host"
: "Amfitrió"

, "Port (Default: 143 / SSL: 993)"
: "Port (per defecte: 143 / SSL: 993)"

, "Secure Connection"
: "Connexió segura"

, "None"
: "Cap"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Nom d'usuari"

, "Password"
: "Contrasenya"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Port (per defecte: 25)"

, "Authentication"
: "Autenticació"

, "Login"
: "Inici de sessió"

, "Plain"
: "Pla"

, "Username (optional)"
: "Nom d'usuari (opcional)"

, "Password (optional)"
: "Contrasenya (opcional)"

, "Test SMTP Connection"
: ""

, "Sieve"
: ""

, "Port (Default: 2000)"
: ""

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Altres paràmetres"

, "Sent Folder Name"
: "Nom de la carpeta Enviats"

, "Trash Folder Name"
: "Nom de la carpeta Paperera"

, "Drafts Folder Name"
: ""

, "Templates Folder Name"
: ""

, "Display Format"
: "Format de visualització"

, "HTML"
: "HTML"

, "Plain Text"
: "Text pla"

, "Depending on content type (experimental)"
: ""

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: ""

, "Toggle highlighting"
: ""

, "Mark read/unread"
: "Marca com a llegit/no llegit"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Afegeix un compte"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Identificador"

, "Attachments"
: "Adjunts"

, "Flags"
: ""

, "Subject"
: "Assumpte"

, "From (Email)"
: ""

, "From (Name)"
: ""

, "Sender"
: ""

, "To"
: "A"

, "Sent"
: "Enviat"

, "Received"
: "Rebut"

, "Folder, Folders"
: [
  "Carpeta"
 ,"Carpetes"

]
, "Size"
: "Mida"

, "Answered"
: "Contestat"

, "Forwarded"
: "Reenviat"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: ""

, "Do you want to send a reading confirmation message?"
: ""

, "Empty Folder"
: "Carpeta buida"

, "Add Folder"
: "Afegeix una carpeta"

, "New {0}"
: "Nou {0}"

, "Please enter the name of the new {0}:"
: "Introduïu el nom del nou {0}:"

, "No {0} added"
: "No s'ha afegit cap {0}"

, "You have to supply a {0} name!"
: "Heu de proporcionar un nom de {0}!"

, "Please wait"
: "Espereu"

, "Creating {0}..."
: "Es crea el {0}..."

, "Edit Account"
: "Edita compte"

, "Edit Vacation Message"
: ""

, "Edit Filter Rules"
: ""

, "Notifications"
: ""

, "Mark Folder as read"
: ""

, "Update Folder List"
: ""

, "Message not available."
: ""

, "Cancel"
: ""

, "Ok"
: ""

, "Folders of account {0}"
: ""

, "Folders of all accounts"
: ""

, "Compose email"
: ""

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "Des de"

, "Add"
: "Afegeix"

, "Add contact to addressbook"
: "Afegeix un contacte a la llibreta d'adreces"

, "Date"
: "Data"

, "Show or hide header information"
: "Mostra o amaga la informació de capçalera"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: ""

, "Select recipients for \"{0}\""
: ""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: ""

, "All recipients"
: ""

, "\"{0}\" recipients"
: ""

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: ""

, "Notification for {0}"
: ""

, "Move up"
: ""

, "Move down"
: ""

, "Enable"
: ""

, "Disable"
: ""

, "ID"
: ""

, "Conditions"
: ""

, "Action"
: ""

, "Keep a copy"
: ""

, "is greater than"
: ""

, "is less than"
: ""

, "Header \"{0}\" contains \"{1}\""
: ""

, "Header \"{0}\" matches \"{1}\""
: ""

, "Sieve Filter Rules"
: ""

, "Sieve Filter Rules for {0}"
: ""

, "From (Email and Name)"
: ""

, "To (Email)"
: ""

, "To (Email CC)"
: ""

, "Header contains"
: ""

, "Header name"
: ""

, "Header value"
: ""

, "Header regex"
: ""

, "Edit Filter Rule"
: ""

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: ""

, "Move mail to folder"
: ""

, "Redirect mail to address"
: ""

, "Reject mail with this text"
: ""

, "Discard mail"
: ""

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: ""

, "General"
: ""

, "Advanced"
: ""

, "Only send all X days to the same sender"
: ""

, "Incoming mails will be answered with this text:"
: ""

, "Status"
: ""

, "I am available (vacation message disabled)"
: ""

, "I am not available (vacation message enabled)"
: ""

, "Start Date"
: ""

, "Set vacation start date ..."
: ""

, "End Date"
: ""

, "Set vacation end date ..."
: ""

, "Representative #1"
: ""

, "Choose first Representative ..."
: ""

, "Representative #2"
: ""

, "Choose second Representative ..."
: ""

, "Message Template"
: ""

, "Choose Template ..."
: ""

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Missatge"
 ,"Missatges"

]
, "Subject/From"
: "Assumpte/Des de"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "INBOX"
: ""

, "Drafts"
: ""

, "Templates"
: ""

, "Junk"
: ""

, "Trash"
: ""

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "llista de registres"
 ,"llistes de registres"

]
, "Rule, Rules"
: [
  ""
 ,""

]
, "Flag, Flags"
: [
  ""
 ,""

]
, "Flag list, Flag lists"
: [
  ""
 ,""

]
, "Total Messages:"
: ""

, "Unread Messages:"
: ""

, "Name on Server:"
: ""

, "Last update:"
: ""

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  ""
 ,""

]
, "New Mail"
: ""

, "Email"
: "Correu electrònic"

, "Active Vacation Message"
: ""

, "Email account \"{0}\" has an active vacation message."
: ""

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "Nous correus"

, "You got {0} new mail(s) in folder {1} ({2})."
: ""

, "IMAP Credentials for {0}"
: "Credencials IMAP per a {0}"

, "Credentials"
: "Credencials"

, "IMAP Error"
: ""

, "No connection to IMAP server."
: "Sense connexió amb el servidor IMAP."

, "IMAP Credentials Error"
: ""

, "Your email credentials are wrong. Please contact your administrator"
: ""

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: ""

, "SMTP Error"
: ""

, "No connection to SMTP server."
: ""

, "Sieve Error"
: ""

, "No connection to Sieve server."
: ""

, "Save Sieve Script Error"
: ""

, "Could not save script on Sieve server."
: ""

, "Add as \"To\""
: ""

, "Add as \"Cc\""
: ""

, "Add as \"Bcc\""
: ""

, "Remove from recipients"
: ""

, "Loading Mail Addresses"
: ""

, "Click here to set To/CC/BCC."
: ""

, "To:"
: "A:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: "Elimina"

, "Send"
: "Envia"

, "Search Recipients"
: ""

, "Save As Draft"
: ""

, "Save As Template"
: ""

, "Reading Confirmation"
: ""

, "Activate this toggle button to receive a reading confirmation."
: ""

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: ""

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: ""

, "{0} Message"
: ""

, "Failed"
: "Ha fallat"

, "{0} account setting empty."
: ""

, "Files are still uploading."
: ""

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: ""

, "Original message"
: "missatge original"

, "Compose email:"
: "Redacta correu electrònic:"

, "Convert to formated text"
: ""

, "Body"
: "Cos"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: ""

, "Do you really want to send a message with an empty subject?"
: ""

, "No recipients set."
: ""

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: ""

, "Default Email Account"
: "Compte de correu electrònic per defecte"

, "The default email account to use when sending mails."
: "Compte de correu electrònic a utilitzar per defecte per a l'enviament de correus."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "Interval d'actualització de correu electrònic"

, "How often should Felamimail check for new Emails (in minutes)."
: ""

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Utilitzeu per a NOTES"

, "Save Note default Value."
: "Desa el valor per defecte Nota."

, "Confirm Delete"
: "Confirma l'eliminació"

, "Show confirmation dialog when deleting mails."
: "Mostra un diàleg de confirmació quan s'eliminin correus electrònics."

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: ""

, "User is allowed to set custom vacation message for system account"
: ""

, "Cache email body"
: ""

, "Should the email body be cached (recommended for slow IMAP server connections)"
: ""

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: ""

, "Your message:"
: ""

, "Received on"
: ""

, "Was read by:"
: ""

, "on"
: ""

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: ""

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: ""

, "Could not send message"
: ""

, "My Mail Download Links"
: ""

, "Seen"
: ""

, "Deleted"
: ""

, "Draft"
: ""

, "Flagged"
: ""

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: ""

, "All unread mail"
: ""

, "All unread mail of my email accounts"
: ""

, "All highlighted mail"
: ""

, "All highlighted mail of my email accounts"
: ""

, "All drafts"
: ""

, "All mails with the draft flag"
: ""

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "gestiona els comptes de correu electrònic"

, "Edit and delete email accounts"
: "Edita i elimina comptes de correu electrònic"

, "Add email accounts"
: "Afegeix comptes de correu electrònic"

, "Create new email accounts"
: "Crea noves comptes de correu electrònic"

, "Vacation"
: ""

, "Account"
: "Compte"

, "Folder"
: "Carpeta"

, "Message"
: "Missatge"

, "record list"
: "llista de registres"

, "Rule"
: ""

, "Flag"
: ""

, "Flag list"
: ""

, "{0} unread message"
: ""

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
